==> tw-api-5.1.29-20240806.090612-1-sources.jar: com/elitesland/tw/tw5/api/prd/my/vo/PmsTimesheetExcel.java <==
package com.elitesland.tw.tw5.api.prd.my.vo;

import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;
import com.elitesland.tw.tw5.api.udc.UdcName;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.util.StringUtils;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

/**
 * 工时表
 *
 * @author duwh
 * @date 2022-12-09
 */
@Data
@ExcelIgnoreUnannotated
public class PmsTimesheetExcel {

    private static final DateTimeFormatter FORMATTER = DateTimeFormatter.ofPattern("yyyy-MM-dd");
    private static final DateTimeFormatter FORMATTER_TIME = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

    /**
     * 填报用户id
     */
    private Long tsUserId;
    @ExcelProperty(index = 2, value = "填报人")
    @UdcName(udcName = "USER", codePropName = "tsUserId")
    private String tsUserIdName;
    /**
     * 填报Bu主键
     */
    private Long tsUserBuId;
    /**
     * 填报Bu名称
     */
    @ExcelProperty(index = 3, value = "填报人部门")
    @UdcName(udcName = "BU", codePropName = "tsUserBuId")
    private String tsUserBuName;
    /** 状态 */
    /**
     * see TimesheetStatus
     * 状态 - T_TIMESHEET.TS_STATUS
     * TSK:TIMESHEET_STATUS	新建	CREATE
     * TSK:TIMESHEET_STATUS	审批中	APPROVING
     * TSK:TIMESHEET_STATUS	已审批	APPROVED
     * TSK:TIMESHEET_STATUS	已结算	SETTLED
     * TSK:TIMESHEET_STATUS	已退回	REJECTED
     */
    private String tsStatus;
    @ExcelProperty(index = 1, value = "状态")
    @UdcName(udcName = "prd:timesheet:status", codePropName = "tsStatus")
    private String tsStatusDesc;
    /**
     * 类型
     */
    private String type;
    /**
     * 审批用户id
     */
    private Long apprUserId;
    /**
     * 审批用户姓名
     */
    @UdcName(udcName = "USER", codePropName = "apprUserId")
    @ExcelProperty(index = 11, value = "当前审批人")
    private String apprUserIdName;
    /**
     * 客户经营计划主键
     */
    private Long operPlanId;
    /**
     * 客户经营计划名称冗余
     */
    // @ExcelProperty(index = 9, value = "经营计划")
    private String operPlanName;
    /**
     * 项目id
     */
    private Long projId;
    /**
     * 项目编号冗余
     */
    private String projNo;
    /**
     * 项目名称
     */
    // @ExcelProperty(index = 5, value = "项目")
    private String projName;


    /**
     * 任务包id
     */
    private Long taskPackageId;
    /**
     * 任务包编号 冗余
     */
    private String taskPackageNo;
    /**
     * 任务包名称冗余
     */
    // @ExcelProperty(index = 6, value = "任务")
    private String taskPackageName;

    /**
     * 项目阶段id（活动阶段）
     */
    private Long stageId;
    /**
     * 项目阶段编号（冗余）
     */
    private String stageNo;

    /**
     * 项目归属部门
     */
    @ExcelProperty(index = 5, value = "项目归属部门")
    private String projectBuName;

    /**
     * 项目阶段名称冗余
     */
    @ExcelProperty(index = 6, value = "项目阶段")
    private String stageName;

    @ApiModelProperty("事由id")
    private Long reasonId;
    @ApiModelProperty("事由名称")
    @ExcelProperty(index = 4, value = "项目")
    private String reasonName;
    @ApiModelProperty("事由类型 PROJ_CONTRACT 合同项目 PROJ_OPPO 售前商机项目 PROJ_BU bu项目")
    private String reasonType;

    private String baseCityId;
    @UdcName(udcName = "org:employee:serviceaddr", codePropName = "baseCityId")
    // @ExcelProperty(index = 9, value = "地点")
    private String baseCityName;

    public Long getTaskPackageId() {
        if (taskPackageId == null) {
            // if (StringUtils.hasText(type) && type.equals("DEV_OPS")) {
            //     return taskPackageId;
            // }
            if (projId != null && projId != 0) {
                return null;
            }
            taskPackageId = 0L;
        }
        return taskPackageId;
    }

    public String getTaskPackageName() {
        if (taskPackageId == null || (taskPackageId != null && taskPackageId.equals(0L))) {
            if (projId != null && projId != 0) {
                return null;
            }
            return "无任务";
        }
        return taskPackageName;
    }

    /**
     * 任务id
     */
    private Long taskId;

    public Long getTaskId() {
        if (taskId == null) {
            if (StringUtils.hasText(type) && type.equals("DEV_OPS")) {
                return taskId;
            }
            taskId = 0L;
        }
        return taskId;
    }

    public String getTaskName() {
        if (StringUtils.hasText(type) && type.equals("DEV_OPS")) {
            return taskName;
        }
        if (taskId == null || (taskId != null && taskId.equals(0L))) {
            return "无任务";
        }
        return taskName;
    }

    /**
     * 任务编号冗余
     */
    private String taskNo;
    /**
     * 任务名称冗余
     */
    // @ExcelProperty(index = 6, value = "任务")
    // @ExcelProperty(index = 7, value = "活动")
    private String taskName;
    /**
     * 任务包申请状态 see TimesheetStatus
     */
    private String taskApplyStatus;
    /**
     * 活动id
     */
    private Long actId;
    /**
     * 活动名称冗余
     */
    //@ExcelProperty(index = 7, value = "活动")
    private String actName;
    /**
     * 活动编号冗余
     */
    private String actNo;
    /**
     * 当量
     */
    private BigDecimal eqva;
    /**
     * 11上午、22下午、33全天、44自定义
     */
    private String workType;
    /**
     * 工作日期
     */
    private LocalDate workDate;

    @ExcelProperty(index = 0, value = "工作日期")
    private String workDateStr;

    public String getWorkDateStr() {
        if (null != workDate) {
            return FORMATTER.format(workDate);
        }
        return workDateStr;
    }

    /**
     * 工时
     */
    private BigDecimal workHour;
    @ExcelProperty(index = 8, value = "工时")
    private String workHourStr;

    public String getWorkHourStr() {
        if (null != workHour) {
            return workHour.toString();
        }
        return workHourStr;
    }

    public String getSubsidyAmtStr() {
        if (null != subsidyAmt) {
            return subsidyAmt.toString();
        }
        return subsidyAmtStr;
    }

    /**
     * 工作说明
     */
    @ExcelProperty(index = 10, value = "工作日志")
    private String workDesc;
    /**
     * 本周开始日期
     */
    private LocalDate weekStartDate;
    /**
     * 本周结束日期
     */
    private LocalDate weekEndDate;

    public LocalDate getWeekEndDate() {
        if (null != weekStartDate) {
            return weekStartDate.plusDays(7);
        }
        return weekEndDate;
    }

    /**
     * 所在年周
     */
    private Integer yearWeek;
    /**
     * 总计人天
     */
    private BigDecimal totalManday;
    /**
     * 总计小时数
     */
    private BigDecimal totalWorkHour;
    /**
     * 审批状态
     */
    private String apprStatus;
    /**
     * 任务标识
     */
    private String tsTaskIden;
    /**
     * 活动标识
     */
    private String tsActIden;
    @UdcName(udcName = "prd:timesheet:notask", codePropName = "tsActIden")
    private String tsActIdenDesc;
    /**
     * 结算状态
     */
    private String settleStatus;
    /**
     * 审批状态
     */
    private String apprResult;
    /** 是否加班、udc >> yesno */
    //private String workFlag;
    /** 可生成调休天数 */
    //private Float workDayOff;
    /** 相关加班安排id */
    //private Integer workRelId;
    /**
     * 可生成调休天数的状态
     */
    private String workDayOffStatus;
    /**
     * 工作计划id
     */
    private Long workPlanId;
    /**
     * 拓展1
     */
    private String ext1;
    /**
     * 拓展2
     */
    private String ext2;
    /**
     * 拓展3
     */
    private String ext3;
    /**
     * 拓展4
     */
    private String ext4;
    @ExcelProperty(index = 7, value = "补助类型")
    @UdcName(udcName = "prd:timesheet:subsidy_select_type_code", codePropName = "ext4")
    private String ext4Desc;
    /**
     * 拓展5
     */
    private String ext5;

    /**
     * 关联任务包的当量系数
     */
    private BigDecimal eqvaRatio;

    /**
     * 工时占用的任务包的当量
     */
    private BigDecimal eqvaTimeSheet;

    /**
     * 补助金额
     */
    @ApiModelProperty("补助金额")
    private BigDecimal subsidyAmt;
    @ExcelProperty(index = 9, value = "补助")
    private String subsidyAmtStr;

    /**
     * 根据 当量系数 工时计算当量
     *
     * @return
     */
    public BigDecimal getEqvaTimeSheet() {
        if (this.eqvaTimeSheet != null) {
            return this.eqvaTimeSheet;
        }
        if (this.eqvaRatio != null && this.getWorkHour() != null) {
            return this.eqvaRatio.multiply(this.getWorkHour()).divide(BigDecimal.valueOf(8), 2, RoundingMode.DOWN);//向下取整数
        }
        return null;
    }

    private String acceptMethod;// 任务包的验收方式
    /**
     * 审批时间
     */
    private LocalDateTime approvalTime;
    // @ExcelProperty(index = 12, value = "审批时间")
    private String approvalTimeStr;

    public String getApprovalTimeStr() {
        if (null != approvalTime) {
            return FORMATTER_TIME.format(approvalTime);
        }
        return approvalTimeStr;
    }

    /**
     * 提交时间
     */
    private LocalDateTime submitTime;
    @ExcelProperty(index = 12, value = "首次提交时间")
    private String submitTimeStr;

    public String getSubmitTimeStr() {
        if (null != submitTime) {
            return FORMATTER_TIME.format(submitTime);
        }
        return submitTimeStr;
    }

    /**
     * 最后提交时间
     */
    private LocalDateTime lastSubmitTime;
    @ExcelProperty(index = 13, value = "工时更新时间")
    private String lastSubmitTimeStr;

    public String getLastSubmitTimeStr() {
        if (null != lastSubmitTime) {
            return FORMATTER_TIME.format(lastSubmitTime);
        }
        return lastSubmitTimeStr;
    }

    // @ExcelProperty(index = 13, value = "备注")
    private String remark;

}

==> tw-api-5.1.77-20240929.134936-1-sources.jar: com/elitesland/tw/tw5/api/prd/my/vo/PmsTimesheetExcel.java <==
package com.elitesland.tw.tw5.api.prd.my.vo;

import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;
import com.elitesland.tw.tw5.api.udc.UdcName;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.util.StringUtils;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

/**
 * 工时表
 *
 * @author duwh
 * @date 2022-12-09
 */
@Data
@ExcelIgnoreUnannotated
public class PmsTimesheetExcel {

    private static final DateTimeFormatter FORMATTER = DateTimeFormatter.ofPattern("yyyy-MM-dd");
    private static final DateTimeFormatter FORMATTER_TIME = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");


    @ExcelProperty(index = 0, value = "工作日期")
    private String workDateStr;

    public String getWorkDateStr() {
        if (null != workDate) {
            return FORMATTER.format(workDate);
        }
        return workDateStr;
    }

    /** 状态 */
    /**
     * see TimesheetStatus
     * 状态 - T_TIMESHEET.TS_STATUS
     * TSK:TIMESHEET_STATUS	新建	CREATE
     * TSK:TIMESHEET_STATUS	审批中	APPROVING
     * TSK:TIMESHEET_STATUS	已审批	APPROVED
     * TSK:TIMESHEET_STATUS	已结算	SETTLED
     * TSK:TIMESHEET_STATUS	已退回	REJECTED
     */
    private String tsStatus;
    @ExcelProperty(index = 1, value = "状态")
    @UdcName(udcName = "prd:timesheet:status", codePropName = "tsStatus")
    private String tsStatusDesc;



    /**
     * 填报用户id
     */
    private Long tsUserId;
    @ExcelProperty(index = 2, value = "填报人")
    @UdcName(udcName = "USER", codePropName = "tsUserId")
    private String tsUserIdName;
    /**
     * 填报Bu主键
     */
    private Long tsUserBuId;
    /**
     * 填报Bu名称
     */
    @ExcelProperty(index = 3, value = "填报人部门")
    @UdcName(udcName = "BU", codePropName = "tsUserBuId")
    private String tsUserBuName;


    /**
     * 岗位
     */
    @ExcelProperty(index = 4, value = "岗位")
    private String jobsName;

    @ApiModelProperty("事由名称")
    @ExcelProperty(index = 5, value = "项目")
    private String reasonName;

    /**
     * 项目归属部门
     */
    @ExcelProperty(index = 6, value = "项目归属部门")
    private String projectBuName;



    /**
     * 项目阶段名称冗余
     */
    @ExcelProperty(index = 7, value = "项目阶段")
    private String stageName;

    /**
     * 拓展4
     */
    private String ext4;
    @ExcelProperty(index = 8, value = "补助类型")
    @UdcName(udcName = "prd:timesheet:subsidy_select_type_code", codePropName = "ext4")
    private String ext4Desc;

    /**
     * 工时
     */
    private BigDecimal workHour;
    @ExcelProperty(index = 9, value = "工时")
    private String workHourStr;

    public String getWorkHourStr() {
        if (null != workHour) {
            return workHour.toString();
        }
        return workHourStr;
    }

    /**
     * 补助金额
     */
    @ApiModelProperty("补助金额")
    private BigDecimal subsidyAmt;
    @ExcelProperty(index = 10, value = "补助")
    private String subsidyAmtStr;
    public String getSubsidyAmtStr() {
        if (null != subsidyAmt) {
            return subsidyAmt.toString();
        }
        return subsidyAmtStr;
    }

    private String baseCityId;
    @UdcName(udcName = "org:employee:serviceaddr", codePropName = "baseCityId")
    @ExcelProperty(index = 11, value = "归属地")
    private String baseCityName;

    private String admCity;
    @UdcName(udcName = "SYSTEM_BASIC:PCD", codePropName = "admCity")
    @ExcelProperty(index = 12, value = "所在城市")
    private String admCityName;

    /**
     * 工作说明
     */
    @ExcelProperty(index = 13, value = "工作日志")
    private String workDesc;

    /**
     * 审批用户姓名
     */
    @UdcName(udcName = "USER", codePropName = "apprUserId")
    @ExcelProperty(index = 14, value = "当前审批人")
    private String apprUserIdName;


    /**
     * 提交时间
     */
    private LocalDateTime submitTime;
    @ExcelProperty(index = 15, value = "首次提交时间")
    private String submitTimeStr;

    public String getSubmitTimeStr() {
        if (null != submitTime) {
            return FORMATTER_TIME.format(submitTime);
        }
        return submitTimeStr;
    }

    /**
     * 最后提交时间
     */
    private LocalDateTime lastSubmitTime;
    @ExcelProperty(index = 16, value = "工时更新时间")
    private String lastSubmitTimeStr;

    public String getLastSubmitTimeStr() {
        if (null != lastSubmitTime) {
            return FORMATTER_TIME.format(lastSubmitTime);
        }
        return lastSubmitTimeStr;
    }

    /**
     * 任务id
     */
    private Long taskId;

    public Long getTaskId() {
        if (taskId == null) {
            if (StringUtils.hasText(type) && type.equals("DEV_OPS")) {
                return taskId;
            }
            taskId = 0L;
        }
        return taskId;
    }

    public String getTaskName() {
        if (StringUtils.hasText(type) && type.equals("DEV_OPS")) {
            return taskName;
        }
        if (taskId == null || (taskId != null && taskId.equals(0L))) {
            return "无任务";
        }
        return taskName;
    }

    /**
     * 任务编号冗余
     */
    private String taskNo;
    /**
     * 任务名称冗余
     */
    // @ExcelProperty(index = 6, value = "任务")
    // @ExcelProperty(index = 7, value = "活动")
    private String taskName;
    /**
     * 任务包申请状态 see TimesheetStatus
     */
    private String taskApplyStatus;
    /**
     * 活动id
     */
    private Long actId;
    /**
     * 活动名称冗余
     */
    //@ExcelProperty(index = 7, value = "活动")
    private String actName;
    /**
     * 活动编号冗余
     */
    private String actNo;
    /**
     * 当量
     */
    private BigDecimal eqva;
    /**
     * 11上午、22下午、33全天、44自定义
     */
    private String workType;
    /**
     * 工作日期
     */
    private LocalDate workDate;






    /**
     * 本周开始日期
     */
    private LocalDate weekStartDate;
    /**
     * 本周结束日期
     */
    private LocalDate weekEndDate;

    public LocalDate getWeekEndDate() {
        if (null != weekStartDate) {
            return weekStartDate.plusDays(7);
        }
        return weekEndDate;
    }

    /**
     * 所在年周
     */
    private Integer yearWeek;
    /**
     * 总计人天
     */
    private BigDecimal totalManday;
    /**
     * 总计小时数
     */
    private BigDecimal totalWorkHour;
    /**
     * 审批状态
     */
    private String apprStatus;
    /**
     * 任务标识
     */
    private String tsTaskIden;
    /**
     * 活动标识
     */
    private String tsActIden;
    @UdcName(udcName = "prd:timesheet:notask", codePropName = "tsActIden")
    private String tsActIdenDesc;
    /**
     * 结算状态
     */
    private String settleStatus;
    /**
     * 审批状态
     */
    private String apprResult;
    /** 是否加班、udc >> yesno */
    //private String workFlag;
    /** 可生成调休天数 */
    //private Float workDayOff;
    /** 相关加班安排id */
    //private Integer workRelId;
    /**
     * 可生成调休天数的状态
     */
    private String workDayOffStatus;
    /**
     * 工作计划id
     */
    private Long workPlanId;
    /**
     * 拓展1
     */
    private String ext1;
    /**
     * 拓展2
     */
    private String ext2;
    /**
     * 拓展3
     */
    private String ext3;

    /**
     * 拓展5
     */
    private String ext5;

    /**
     * 关联任务包的当量系数
     */
    private BigDecimal eqvaRatio;

    /**
     * 工时占用的任务包的当量
     */
    private BigDecimal eqvaTimeSheet;



    /**
     * 根据 当量系数 工时计算当量
     *
     * @return
     */
    public BigDecimal getEqvaTimeSheet() {
        if (this.eqvaTimeSheet != null) {
            return this.eqvaTimeSheet;
        }
        if (this.eqvaRatio != null && this.getWorkHour() != null) {
            return this.eqvaRatio.multiply(this.getWorkHour()).divide(BigDecimal.valueOf(8), 2, RoundingMode.DOWN);//向下取整数
        }
        return null;
    }

    private String acceptMethod;// 任务包的验收方式
    /**
     * 审批时间
     */
    private LocalDateTime approvalTime;
    // @ExcelProperty(index = 12, value = "审批时间")
    private String approvalTimeStr;

    public String getApprovalTimeStr() {
        if (null != approvalTime) {
            return FORMATTER_TIME.format(approvalTime);
        }
        return approvalTimeStr;
    }



    // @ExcelProperty(index = 13, value = "备注")
    private String remark;

    /**
     * 客户经营计划主键
     */
    private Long operPlanId;
    /**
     * 客户经营计划名称冗余
     */
    // @ExcelProperty(index = 9, value = "经营计划")
    private String operPlanName;
    /**
     * 项目id
     */
    private Long projId;
    /**
     * 项目编号冗余
     */
    private String projNo;
    /**
     * 项目名称
     */
    // @ExcelProperty(index = 5, value = "项目")
    private String projName;


    /**
     * 任务包id
     */
    private Long taskPackageId;
    public Long getTaskPackageId() {
        if (taskPackageId == null) {
            // if (StringUtils.hasText(type) && type.equals("DEV_OPS")) {
            //     return taskPackageId;
            // }
            if (projId != null && projId != 0) {
                return null;
            }
            taskPackageId = 0L;
        }
        return taskPackageId;
    }
    /**
     * 任务包编号 冗余
     */
    private String taskPackageNo;
    /**
     * 任务包名称冗余
     */
    private String taskPackageName;

    public String getTaskPackageName() {
        if (taskPackageId == null || (taskPackageId != null && taskPackageId.equals(0L))) {
            if (projId != null && projId != 0) {
                return null;
            }
            return "无任务";
        }
        return taskPackageName;
    }

    /**
     * 项目阶段id（活动阶段）
     */
    private Long stageId;
    /**
     * 项目阶段编号（冗余）
     */
    private String stageNo;

    /**
     * 类型
     */
    private String type;
    /**
     * 审批用户id
     */
    private Long apprUserId;

    @ApiModelProperty("事由id")
    private Long reasonId;

    @ApiModelProperty("事由类型 PROJ_CONTRACT 合同项目 PROJ_OPPO 售前商机项目 PROJ_BU bu项目")
    private String reasonType;

}
